# Key Features

<Tabs>
  <Tab title="Chat Panel">
    * Displays the conversation between the user and OpenHands.
    * OpenHands explains its actions in this panel.

        <img src="https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/chat-panel.png?fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=b035e1775e0ce9ea64fe497748350083" alt="overview" data-og-width="1236" width="1236" data-og-height="749" height="749" data-path="openhands/static/img/chat-panel.png" data-optimize="true" data-opv="3" srcset="https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/chat-panel.png?w=280&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=4ad5936fae60e5a09f6531ce42892813 280w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/chat-panel.png?w=560&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=69f6d135ea91efbb8d013fd76aefcc65 560w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/chat-panel.png?w=840&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=d2e4fa082bcdcde1ea21ae1629cb4a44 840w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/chat-panel.png?w=1100&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=aa7913113e9743c1cc723fa2a527f3f8 1100w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/chat-panel.png?w=1650&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=50f5af64689ba1e8ca162ad17faf784f 1650w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/chat-panel.png?w=2500&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=0648a89b19fdc2d685fb91816cff31f1 2500w" />
  </Tab>

  <Tab title="Changes Tab">
    * Shows the file changes performed by OpenHands.

        <img src="https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/changes-tab.png?fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=33541d439b3799dd8bb2d29a1bbbe3a8" alt="overview" data-og-width="1236" width="1236" data-og-height="744" height="744" data-path="openhands/static/img/changes-tab.png" data-optimize="true" data-opv="3" srcset="https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/changes-tab.png?w=280&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=e68abec2b1c11d61ccc0ad764938ea08 280w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/changes-tab.png?w=560&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=6825039a7ad84cb19436b47ff6cbc6f0 560w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/changes-tab.png?w=840&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=dffa09de633b169f4b938a4b88121ad4 840w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/changes-tab.png?w=1100&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=c1324a33bf90dc04bbb570df77a6ef3b 1100w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/changes-tab.png?w=1650&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=ddc6b1b4b7bdec52ce547ed4bba0d939 1650w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/changes-tab.png?w=2500&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=7b8e713f2526142a8238eb98ecef8d96 2500w" />
  </Tab>

  <Tab title="VS Code">
    * Embedded VS Code for browsing and modifying files.
    * Can also be used to upload and download files.

        <img src="https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/vs-tab.png?fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=cdeebb556cd230ac83c78a01f11b36c2" alt="overview" data-og-width="1236" width="1236" data-og-height="742" height="742" data-path="openhands/static/img/vs-tab.png" data-optimize="true" data-opv="3" srcset="https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/vs-tab.png?w=280&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=a7bf993faf3d78714c8d4180a94f6495 280w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/vs-tab.png?w=560&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=da3d9583e2a6394b97ac01ab7f7e6b94 560w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/vs-tab.png?w=840&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=1fc2ca048c0d255f1bdbdbfd3b817c3f 840w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/vs-tab.png?w=1100&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=96b5fe145c1a302ebb4f378551cbc509 1100w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/vs-tab.png?w=1650&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=418763c9a7acd2c51c80ddeff98623a5 1650w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/vs-tab.png?w=2500&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=e5b8a45c84cf5b3498df035caa83dc57 2500w" />
  </Tab>

  <Tab title="Terminal Tab">
    * A space for OpenHands and users to run terminal commands.

        <img src="https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/terminal-tab.png?fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=66a37d2508015e4dcf9788fcfeb2d604" alt="overview" data-og-width="1235" width="1235" data-og-height="747" height="747" data-path="openhands/static/img/terminal-tab.png" data-optimize="true" data-opv="3" srcset="https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/terminal-tab.png?w=280&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=77d2386a2d78284ae67dc6d78ca9119b 280w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/terminal-tab.png?w=560&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=42b108c5a3d50381cfb7cbf93491d4c1 560w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/terminal-tab.png?w=840&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=787d0b864dd4da836791abb9d02a6c59 840w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/terminal-tab.png?w=1100&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=dc0c832ae028b29c064b3786cd8e3333 1100w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/terminal-tab.png?w=1650&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=f5555a2a69c68a8750585edae1f9da14 1650w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/terminal-tab.png?w=2500&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=ddcadc129529babe61f2603d186e3db6 2500w" />
  </Tab>

  <Tab title="App Tab">
    * Displays the web server when OpenHands runs an application.
    * Users can interact with the running application.

        <img src="https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/app-tab.png?fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=091198331b8174d893a127327cbcc28d" alt="overview" data-og-width="1236" width="1236" data-og-height="746" height="746" data-path="openhands/static/img/app-tab.png" data-optimize="true" data-opv="3" srcset="https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/app-tab.png?w=280&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=a288e99577c0354fa1e07b09e9b47a76 280w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/app-tab.png?w=560&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=e7b9cb8389573c40f4f78aae5da4ad8c 560w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/app-tab.png?w=840&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=03122ab556e1a707a4b0fbdd5e54d56f 840w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/app-tab.png?w=1100&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=13efb669df785c1cb8e1b53c00e1a891 1100w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/app-tab.png?w=1650&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=1045a582dd7e5aeaec2a0abfe923d733 1650w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/app-tab.png?w=2500&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=6e1979d84934add0c21f9e6bf41b9aa0 2500w" />
  </Tab>

  <Tab title="Browser Tab">
    * Used by OpenHands to browse websites.
    * The browser is non-interactive.

        <img src="https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/browser-tab.png?fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=7125021986fa4954aaba4913ce5f6345" alt="overview" data-og-width="1235" width="1235" data-og-height="745" height="745" data-path="openhands/static/img/browser-tab.png" data-optimize="true" data-opv="3" srcset="https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/browser-tab.png?w=280&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=7d5a54842e55fe489b9a10457d249db4 280w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/browser-tab.png?w=560&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=75dfb61a8f5810fa8ad6c250518e1748 560w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/browser-tab.png?w=840&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=e33f79a8d3f1b9b1587c468d0a2b0b00 840w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/browser-tab.png?w=1100&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=f35ea015cb1a5ae11009fd319b901caf 1100w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/browser-tab.png?w=1650&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=56cc1090b44bb68f776074276a336326 1650w, https://mintcdn.com/allhandsai/cODka5vdlu5LNkWx/openhands/static/img/browser-tab.png?w=2500&fit=max&auto=format&n=cODka5vdlu5LNkWx&q=85&s=ae384550618040711056d2c9b00ee3c3 2500w" />
  </Tab>
</Tabs>


---

> To find navigation and other pages in this documentation, fetch the llms.txt file at: https://docs.openhands.dev/llms.txt